var ometajs_ = require("ometajs");

var AbstractGrammar = ometajs_.grammars.AbstractGrammar;

var BSJSParser = ometajs_.grammars.BSJSParser;

var BSJSIdentity = ometajs_.grammars.BSJSIdentity;

var BSJSTranslator = ometajs_.grammars.BSJSTranslator;

var KrasotaJSSerializer = require("krasota").KrasotaJSSerializer;

var YetAnotherJSHighlighter = function YetAnotherJSHighlighter(source, opts) {
    KrasotaJSSerializer.call(this, source, opts);
};

YetAnotherJSHighlighter.grammarName = "YetAnotherJSHighlighter";

YetAnotherJSHighlighter.match = KrasotaJSSerializer.match;

YetAnotherJSHighlighter.matchAll = KrasotaJSSerializer.matchAll;

exports.YetAnotherJSHighlighter = YetAnotherJSHighlighter;

require("util").inherits(YetAnotherJSHighlighter, KrasotaJSSerializer);

YetAnotherJSHighlighter.prototype["spaces"] = function $spaces() {
    var s;
    return this._skip() && (s = this._getIntermediate(), true) && this._exec(s.replace("\n", "<br/>"));
};

YetAnotherJSHighlighter.prototype["comment"] = function $comment() {
    var c;
    return this._skip() && (c = this._getIntermediate(), true) && this._exec(w("comment", c.replace(/^\/\/|^\/\*|\*\/$/g, '<span class="punctuation">$&</span>')));
};

YetAnotherJSHighlighter.prototype["name"] = function $name() {
    var n;
    return this._skip() && (n = this._getIntermediate(), true) && this._exec(w("name", n));
};

YetAnotherJSHighlighter.prototype["keyword"] = function $keyword() {
    return this._atomic(function() {
        var k;
        return this._match("this") && (k = this._getIntermediate(), true) && this._exec(keyword("this", k));
    }) || this._atomic(function() {
        var k;
        return this._match("null") && (k = this._getIntermediate(), true) && this._exec(keyword("null", k));
    }) || this._atomic(function() {
        var k;
        return this._skip() && (k = this._getIntermediate(), true) && this._exec(keyword(k));
    });
};

YetAnotherJSHighlighter.prototype["bool"] = function $bool() {
    var b;
    return this._skip() && (b = this._getIntermediate(), true) && this._exec(w("bool", b));
};

YetAnotherJSHighlighter.prototype["number"] = function $number() {
    return this._atomic(function() {
        var s;
        return (this._match("Infinity") || this._match("NaN")) && (s = this._getIntermediate(), true) && this._exec(w("num", s));
    }) || this._atomic(function() {
        var n;
        return this._skip() && (n = this._getIntermediate(), true) && this._exec(w("num", n.replace(/\D/g, function(c) {
            return punctuation(c).join("");
        })));
    });
};

YetAnotherJSHighlighter.prototype["escapeChar"] = function $escapeChar() {
    var c, u;
    return this._skip() && (c = this._getIntermediate(), true) && this._skip() && (u = this._getIntermediate(), true) && this._exec(w("esc", punctuation("\\"), c));
};

YetAnotherJSHighlighter.prototype["string"] = function $string() {
    var q, c;
    return this._skip() && (q = this._getIntermediate(), true) && this._list(function() {
        return this._any(function() {
            return this._atomic(function() {
                return this._atomic(function() {
                    return this._rule("char", false, [], null, this["char"]);
                }) || this._atomic(function() {
                    var ec;
                    return this._rule("t", false, [], null, this["t"]) && (ec = this._getIntermediate(), true);
                });
            });
        }) && (c = this._getIntermediate(), true);
    }) && this._exec(w("str", punctuation(q), c, punctuation(q)));
};

YetAnotherJSHighlighter.prototype["commaList"] = function $commaList() {
    var x, xs, xx;
    return this._rule("t", false, [], null, this["t"]) && (x = this._getIntermediate(), true) && this._any(function() {
        return this._atomic(function() {
            return this._rule("t", false, [], null, this["t"]) && (xx = this._getIntermediate(), true) && this._exec([ punctuation(","), xx ]);
        });
    }) && (xs = this._getIntermediate(), true) && this._exec([ x, xs ]);
};

YetAnotherJSHighlighter.prototype["op"] = function $op() {
    var s1, o, s2;
    return this._rule("t", false, [], null, this["t"]) && (s1 = this._getIntermediate(), true) && this._skip() && (o = this._getIntermediate(), true) && this._rule("t", false, [], null, this["t"]) && (s2 = this._getIntermediate(), true) && this._exec([ s1, w("op", o), s2 ]);
};

YetAnotherJSHighlighter.prototype["binop"] = function $binop() {
    var e1, o, e2;
    return this._rule("t", false, [], null, this["t"]) && (e1 = this._getIntermediate(), true) && this._rule("t", false, [], null, this["t"]) && (o = this._getIntermediate(), true) && this._rule("t", false, [], null, this["t"]) && (e2 = this._getIntermediate(), true) && this._exec(w("binop", e1, o, e2));
};

YetAnotherJSHighlighter.prototype["unop"] = function $unop() {
    var o, e;
    return this._rule("t", false, [], null, this["t"]) && (o = this._getIntermediate(), true) && this._rule("t", false, [], null, this["t"]) && (e = this._getIntermediate(), true) && this._exec(w("unop", o, e));
};

YetAnotherJSHighlighter.prototype["postop"] = function $postop() {
    var e, s, o;
    return this._rule("t", false, [], null, this["t"]) && (e = this._getIntermediate(), true) && this._rule("t", false, [], null, this["t"]) && (s = this._getIntermediate(), true) && this._skip() && (o = this._getIntermediate(), true) && this._exec(w("postop", e, s, w("op", o)));
};

YetAnotherJSHighlighter.prototype["getExprSB"] = function $getExprSB() {
    var e, s1, s2, i, s3;
    return this._rule("t", false, [], null, this["t"]) && (e = this._getIntermediate(), true) && this._rule("t", false, [], null, this["t"]) && (s1 = this._getIntermediate(), true) && this._rule("t", false, [], null, this["t"]) && (s2 = this._getIntermediate(), true) && this._rule("t", false, [], null, this["t"]) && (i = this._getIntermediate(), true) && this._rule("t", false, [], null, this["t"]) && (s3 = this._getIntermediate(), true) && this._exec([ e, s1, w("get-sb", punctuation("["), s2, i, s3, punctuation("]")) ]);
};

YetAnotherJSHighlighter.prototype["getExprDot"] = function $getExprDot() {
    var e, s1, s2, n;
    return this._rule("t", false, [], null, this["t"]) && (e = this._getIntermediate(), true) && this._rule("t", false, [], null, this["t"]) && (s1 = this._getIntermediate(), true) && this._rule("t", false, [], null, this["t"]) && (s2 = this._getIntermediate(), true) && this._rule("t", false, [], null, this["t"]) && (n = this._getIntermediate(), true) && this._exec([ e, s1, w("get-dot", punctuation(".")), s2, n ]);
};

YetAnotherJSHighlighter.prototype["callExpr"] = function $callExpr() {
    var e, s1, as;
    return this._rule("t", false, [], null, this["t"]) && (e = this._getIntermediate(), true) && this._rule("t", false, [], null, this["t"]) && (s1 = this._getIntermediate(), true) && this._rule("t", false, [], null, this["t"]) && (as = this._getIntermediate(), true) && this._exec([ e, s1, w("call", punctuation("("), as, punctuation(")")) ]);
};

YetAnotherJSHighlighter.prototype["arg"] = function $arg() {
    var s1, e, s2;
    return this._rule("t", false, [], null, this["t"]) && (s1 = this._getIntermediate(), true) && this._rule("t", false, [], null, this["t"]) && (e = this._getIntermediate(), true) && this._rule("t", false, [], null, this["t"]) && (s2 = this._getIntermediate(), true) && this._exec([ s1, e, s2 ]);
};

YetAnotherJSHighlighter.prototype["newExpr"] = function $newExpr() {
    var n;
    return (this._atomic(function() {
        var s1, e, s2, as;
        return this._rule("t", false, [], null, this["t"]) && (s1 = this._getIntermediate(), true) && this._rule("t", false, [], null, this["t"]) && (e = this._getIntermediate(), true) && this._rule("t", false, [], null, this["t"]) && (s2 = this._getIntermediate(), true) && this._rule("t", false, [], null, this["t"]) && (as = this._getIntermediate(), true) && this._exec({
            s1: s1,
            e: e,
            s2: s2,
            as: as
        });
    }) || this._atomic(function() {
        var s1, e;
        return this._rule("t", false, [], null, this["t"]) && (s1 = this._getIntermediate(), true) && this._rule("t", false, [], null, this["t"]) && (e = this._getIntermediate(), true) && this._exec({
            s1: s1,
            e: e
        });
    })) && (n = this._getIntermediate(), true) && this._exec(w("new", keyword("new"), n.s1, n.e, n.s2 || "", n.as ? w("new-call", punctuation("("), n.as, punctuation(")")) : ""));
};

YetAnotherJSHighlighter.prototype["bracketedExpr"] = function $bracketedExpr() {
    var s1, e, s2;
    return this._rule("t", false, [], null, this["t"]) && (s1 = this._getIntermediate(), true) && this._rule("t", false, [], null, this["t"]) && (e = this._getIntermediate(), true) && this._rule("t", false, [], null, this["t"]) && (s2 = this._getIntermediate(), true) && this._exec([ punctuation("("), s1, e, s2, punctuation(")") ]);
};

YetAnotherJSHighlighter.prototype["funcExpr"] = function $funcExpr() {
    return this._atomic(function() {
        var s1, n, s2, c;
        return this._rule("t", false, [], null, this["t"]) && (s1 = this._getIntermediate(), true) && this._rule("t", false, [], null, this["t"]) && (n = this._getIntermediate(), true) && this._rule("t", false, [], null, this["t"]) && (s2 = this._getIntermediate(), true) && this._rule("funcRest", false, [], null, this["funcRest"]) && (c = this._getIntermediate(), true) && this._exec(w("func func-expr", keyword("function"), s1, n, s2, c));
    }) || this._atomic(function() {
        var s1, c;
        return this._rule("t", false, [], null, this["t"]) && (s1 = this._getIntermediate(), true) && this._rule("funcRest", false, [], null, this["funcRest"]) && (c = this._getIntermediate(), true) && this._exec(w("func func-expr", keyword("function"), s1, c));
    });
};

YetAnotherJSHighlighter.prototype["funcRest"] = function $funcRest() {
    var as, s, c;
    return this._rule("t", false, [], null, this["t"]) && (as = this._getIntermediate(), true) && this._rule("t", false, [], null, this["t"]) && (s = this._getIntermediate(), true) && this._rule("t", false, [], null, this["t"]) && (c = this._getIntermediate(), true) && this._exec([ punctuation("("), as, punctuation(")"), s, c ]);
};

YetAnotherJSHighlighter.prototype["funcArg"] = function $funcArg() {
    var s1, n, s2;
    return this._rule("t", false, [], null, this["t"]) && (s1 = this._getIntermediate(), true) && this._rule("t", false, [], null, this["t"]) && (n = this._getIntermediate(), true) && this._rule("t", false, [], null, this["t"]) && (s2 = this._getIntermediate(), true) && this._exec([ s1, w("arg", n), s2 ]);
};

YetAnotherJSHighlighter.prototype["arr"] = function $arr() {
    var c;
    return this._rule("t", false, [], null, this["t"]) && (c = this._getIntermediate(), true) && this._exec(w("arr", punctuation("["), c, punctuation("]")));
};

YetAnotherJSHighlighter.prototype["arrItem"] = function $arrItem() {
    var s1, e, s2;
    return this._rule("t", false, [], null, this["t"]) && (s1 = this._getIntermediate(), true) && this._rule("t", false, [], null, this["t"]) && (e = this._getIntermediate(), true) && this._rule("t", false, [], null, this["t"]) && (s2 = this._getIntermediate(), true) && this._exec([ s1, e, s2 ]);
};

YetAnotherJSHighlighter.prototype["obj"] = function $obj() {
    var c;
    return this._rule("t", false, [], null, this["t"]) && (c = this._getIntermediate(), true) && this._exec(w("obj", punctuation("{"), c, punctuation("}")));
};

YetAnotherJSHighlighter.prototype["objItem"] = function $objItem() {
    var s1, n, s2, s3, v, s4;
    return this._rule("t", false, [], null, this["t"]) && (s1 = this._getIntermediate(), true) && this._rule("t", false, [], null, this["t"]) && (n = this._getIntermediate(), true) && this._rule("t", false, [], null, this["t"]) && (s2 = this._getIntermediate(), true) && this._rule("t", false, [], null, this["t"]) && (s3 = this._getIntermediate(), true) && this._rule("t", false, [], null, this["t"]) && (v = this._getIntermediate(), true) && this._rule("t", false, [], null, this["t"]) && (s4 = this._getIntermediate(), true) && this._exec([ s1, n, s2, punctuation(":"), s3, v, s4 ]);
};

YetAnotherJSHighlighter.prototype["re"] = function $re() {
    var c, f;
    return this._rule("t", false, [], null, this["t"]) && (c = this._getIntermediate(), true) && this._skip() && (f = this._getIntermediate(), true) && this._exec(w("re", c, punctuation(f.join(""))));
};

YetAnotherJSHighlighter.prototype["stmtWithExprAndStmt"] = function $stmtWithExprAndStmt() {
    var k, s1, be, s2, c;
    return this._skip() && (k = this._getIntermediate(), true) && this._rule("t", false, [], null, this["t"]) && (s1 = this._getIntermediate(), true) && this._rule("t", false, [], null, this["t"]) && (be = this._getIntermediate(), true) && this._rule("t", false, [], null, this["t"]) && (s2 = this._getIntermediate(), true) && this._rule("t", false, [], null, this["t"]) && (c = this._getIntermediate(), true) && this._exec([ keyword(k), s1, be, s2, c ]);
};

YetAnotherJSHighlighter.prototype["stmtWithLabel"] = function $stmtWithLabel() {
    var k;
    return this._skip() && (k = this._getIntermediate(), true) && (this._atomic(function() {
        var s, l;
        return this._rule("t", false, [], null, this["t"]) && (s = this._getIntermediate(), true) && this._rule("t", false, [], null, this["t"]) && (l = this._getIntermediate(), true) && this._exec([ keyword(k), s, l ]);
    }) || this._atomic(function() {
        return this._rule("empty", false, [], null, this["empty"]) && this._exec(keyword(k));
    }));
};

YetAnotherJSHighlighter.prototype["blockStmt"] = function $blockStmt() {
    var c;
    return this._rule("t", false, [], null, this["t"]) && (c = this._getIntermediate(), true) && this._exec([ punctuation("{"), c, punctuation("}") ]);
};

YetAnotherJSHighlighter.prototype["stmts"] = function $stmts() {
    var c;
    return this._any(function() {
        return this._atomic(function() {
            return this._rule("t", false, [], null, this["t"]);
        });
    }) && (c = this._getIntermediate(), true) && this._exec(w("stmts", c.map(function(stmt) {
        return w("stmt", stmt);
    })));
};

YetAnotherJSHighlighter.prototype["stmtEnd"] = function $stmtEnd() {
    return this._atomic(function() {
        var s, c;
        return this._rule("t", false, [], null, this["t"]) && (s = this._getIntermediate(), true) && this._match(";") && (c = this._getIntermediate(), true) && this._exec([ s, punctuation(c) ]);
    }) || this._atomic(function() {
        var s, c;
        return this._rule("t", false, [], null, this["t"]) && (s = this._getIntermediate(), true) && this._match("\n") && (c = this._getIntermediate(), true) && this._exec([ s, "<br/>" ]);
    }) || this._atomic(function() {
        var s;
        return this._rule("t", false, [], null, this["t"]) && (s = this._getIntermediate(), true);
    }) || this._atomic(function() {
        return this._rule("empty", false, [], null, this["empty"]) && this._exec("");
    });
};

YetAnotherJSHighlighter.prototype["funcStmt"] = function $funcStmt() {
    var s1, n, s2, c;
    return this._rule("t", false, [], null, this["t"]) && (s1 = this._getIntermediate(), true) && this._rule("t", false, [], null, this["t"]) && (n = this._getIntermediate(), true) && this._rule("t", false, [], null, this["t"]) && (s2 = this._getIntermediate(), true) && this._rule("funcRest", false, [], null, this["funcRest"]) && (c = this._getIntermediate(), true) && this._exec(w("func func-stmt", keyword("function"), s1, n, s2, c));
};

YetAnotherJSHighlighter.prototype["varStmt"] = function $varStmt() {
    var c;
    return this._list(function() {
        return this._many(function() {
            return this._atomic(function() {
                return this._rule("t", false, [], null, this["t"]);
            });
        }) && (c = this._getIntermediate(), true);
    }) && this._exec(w("var", keyword("var"), c.map(function(v, i) {
        return i == c.length - 1 ? v : [ v, punctuation(",") ];
    })));
};

YetAnotherJSHighlighter.prototype["varItemAsgn"] = function $varItemAsgn() {
    var n, s1, s2, e, s3;
    return this._rule("t", false, [], null, this["t"]) && (n = this._getIntermediate(), true) && this._rule("t", false, [], null, this["t"]) && (s1 = this._getIntermediate(), true) && this._rule("t", false, [], null, this["t"]) && (s2 = this._getIntermediate(), true) && this._rule("t", false, [], null, this["t"]) && (e = this._getIntermediate(), true) && this._rule("t", false, [], null, this["t"]) && (s3 = this._getIntermediate(), true) && this._exec([ n, s1, punctuation("="), s2, e, s3 ]);
};

YetAnotherJSHighlighter.prototype["varItemName"] = function $varItemName() {
    var s1, n, s2;
    return this._rule("t", false, [], null, this["t"]) && (s1 = this._getIntermediate(), true) && this._rule("t", false, [], null, this["t"]) && (n = this._getIntermediate(), true) && this._rule("t", false, [], null, this["t"]) && (s2 = this._getIntermediate(), true) && this._exec([ s1, n, s2 ]);
};

YetAnotherJSHighlighter.prototype["ifStmt"] = function $ifStmt() {
    return this._atomic(function() {
        var i, se, s1, s2, e;
        return this._rule("stmtWithExprAndStmt", false, [ "if" ], null, this["stmtWithExprAndStmt"]) && (i = this._getIntermediate(), true) && this._rule("t", false, [], null, this["t"]) && (se = this._getIntermediate(), true) && this._rule("t", false, [], null, this["t"]) && (s1 = this._getIntermediate(), true) && this._rule("t", false, [], null, this["t"]) && (s2 = this._getIntermediate(), true) && this._rule("t", false, [], null, this["t"]) && (e = this._getIntermediate(), true) && this._exec(w("if", i, se, s1, keyword("else"), s2, e));
    }) || this._atomic(function() {
        var i;
        return this._rule("stmtWithExprAndStmt", false, [ "if" ], null, this["stmtWithExprAndStmt"]) && (i = this._getIntermediate(), true) && this._exec(w("if", i));
    });
};

YetAnotherJSHighlighter.prototype["whileStmt"] = function $whileStmt() {
    var c;
    return this._rule("stmtWithExprAndStmt", false, [ "while" ], null, this["stmtWithExprAndStmt"]) && (c = this._getIntermediate(), true) && this._exec(w("while", c));
};

YetAnotherJSHighlighter.prototype["doStmt"] = function $doStmt() {
    var s1, c, s2, s3, be;
    return this._rule("t", false, [], null, this["t"]) && (s1 = this._getIntermediate(), true) && this._rule("t", false, [], null, this["t"]) && (c = this._getIntermediate(), true) && this._rule("t", false, [], null, this["t"]) && (s2 = this._getIntermediate(), true) && this._rule("t", false, [], null, this["t"]) && (s3 = this._getIntermediate(), true) && this._rule("t", false, [], null, this["t"]) && (be = this._getIntermediate(), true) && this._exec(w("do", keyword("do"), s1, c, s2, keyword("while"), s3, be));
};

YetAnotherJSHighlighter.prototype["forStmt"] = function $forStmt() {
    var s1, e, s2, c;
    return this._rule("t", false, [], null, this["t"]) && (s1 = this._getIntermediate(), true) && this._rule("forStmtExprs", false, [], null, this["forStmtExprs"]) && (e = this._getIntermediate(), true) && this._rule("t", false, [], null, this["t"]) && (s2 = this._getIntermediate(), true) && this._rule("t", false, [], null, this["t"]) && (c = this._getIntermediate(), true) && this._exec(w("for", keyword("for"), s1, e, s2, c));
};

YetAnotherJSHighlighter.prototype["forStmtExprs"] = function $forStmtExprs() {
    var e1, e2, e3;
    return this._list(function() {
        return this._rule("t", false, [], null, this["t"]) && (e1 = this._getIntermediate(), true) && this._rule("t", false, [], null, this["t"]) && (e2 = this._getIntermediate(), true) && this._rule("t", false, [], null, this["t"]) && (e3 = this._getIntermediate(), true);
    }) && this._exec([ punctuation("("), e1, punctuation(";"), e2, punctuation(";"), e3, punctuation(")") ]);
};

YetAnotherJSHighlighter.prototype["forStmtExpr"] = function $forStmtExpr() {
    return this._atomic(function() {
        var s1, c, s2;
        return this._rule("t", false, [], null, this["t"]) && (s1 = this._getIntermediate(), true) && this._rule("t", false, [], null, this["t"]) && (c = this._getIntermediate(), true) && this._rule("t", false, [], null, this["t"]) && (s2 = this._getIntermediate(), true) && this._exec([ s1, c, s2 ]);
    }) || this._atomic(function() {
        var s;
        return this._rule("t", false, [], null, this["t"]) && (s = this._getIntermediate(), true);
    });
};

YetAnotherJSHighlighter.prototype["forInStmt"] = function $forInStmt() {
    var s1, e, s2, c;
    return this._rule("t", false, [], null, this["t"]) && (s1 = this._getIntermediate(), true) && this._rule("forInStmtExpr", false, [], null, this["forInStmtExpr"]) && (e = this._getIntermediate(), true) && this._rule("t", false, [], null, this["t"]) && (s2 = this._getIntermediate(), true) && this._rule("t", false, [], null, this["t"]) && (c = this._getIntermediate(), true) && this._exec(w("for", keyword("for"), s1, e, s2, c));
};

YetAnotherJSHighlighter.prototype["forInStmtExpr"] = function $forInStmtExpr() {
    var s1, e1, s2, s3, e2, s4;
    return this._list(function() {
        return this._rule("t", false, [], null, this["t"]) && (s1 = this._getIntermediate(), true) && this._rule("t", false, [], null, this["t"]) && (e1 = this._getIntermediate(), true) && this._rule("t", false, [], null, this["t"]) && (s2 = this._getIntermediate(), true) && this._rule("t", false, [], null, this["t"]) && (s3 = this._getIntermediate(), true) && this._rule("t", false, [], null, this["t"]) && (e2 = this._getIntermediate(), true) && this._rule("t", false, [], null, this["t"]) && (s4 = this._getIntermediate(), true);
    }) && this._exec([ punctuation("("), s1, e1, s2, keyword("in"), s3, e2, s4, punctuation(")") ]);
};

YetAnotherJSHighlighter.prototype["forInStmtVar"] = function $forInStmtVar() {
    var c;
    return this._rule("t", false, [], null, this["t"]) && (c = this._getIntermediate(), true) && this._exec([ keyword("var"), c ]);
};

YetAnotherJSHighlighter.prototype["breakStmt"] = function $breakStmt() {
    var b;
    return this._rule("stmtWithLabel", false, [ "break" ], null, this["stmtWithLabel"]) && (b = this._getIntermediate(), true) && this._exec(w("break", b));
};

YetAnotherJSHighlighter.prototype["continueStmt"] = function $continueStmt() {
    var c;
    return this._rule("stmtWithLabel", false, [ "continue" ], null, this["stmtWithLabel"]) && (c = this._getIntermediate(), true) && this._exec(w("continue", c));
};

YetAnotherJSHighlighter.prototype["switchStmt"] = function $switchStmt() {
    var s1, be, s2, c;
    return this._rule("t", false, [], null, this["t"]) && (s1 = this._getIntermediate(), true) && this._rule("t", false, [], null, this["t"]) && (be = this._getIntermediate(), true) && this._rule("t", false, [], null, this["t"]) && (s2 = this._getIntermediate(), true) && this._rule("t", false, [], null, this["t"]) && (c = this._getIntermediate(), true) && this._exec(w("switch", keyword("switch"), s1, be, s2, c));
};

YetAnotherJSHighlighter.prototype["switchStmtContent"] = function $switchStmtContent() {
    var c;
    return this._list(function() {
        return this._any(function() {
            return this._atomic(function() {
                return this._rule("t", false, [], null, this["t"]);
            });
        }) && (c = this._getIntermediate(), true);
    }) && this._exec([ punctuation("{"), c, punctuation("}") ]);
};

YetAnotherJSHighlighter.prototype["switchStmtItem"] = function $switchStmtItem() {
    var s1, l, s2, s3, c;
    return this._rule("t", false, [], null, this["t"]) && (s1 = this._getIntermediate(), true) && this._rule("t", false, [], null, this["t"]) && (l = this._getIntermediate(), true) && this._rule("t", false, [], null, this["t"]) && (s2 = this._getIntermediate(), true) && this._rule("t", false, [], null, this["t"]) && (s3 = this._getIntermediate(), true) && this._rule("t", false, [], null, this["t"]) && (c = this._getIntermediate(), true) && this._exec([ s1, l, s2, punctuation(":"), s3, c ]);
};

YetAnotherJSHighlighter.prototype["switchStmtCase"] = function $switchStmtCase() {
    var s, e;
    return this._rule("t", false, [], null, this["t"]) && (s = this._getIntermediate(), true) && this._rule("t", false, [], null, this["t"]) && (e = this._getIntermediate(), true) && this._exec([ keyword("case"), s, e ]);
};

YetAnotherJSHighlighter.prototype["switchStmtDefault"] = function $switchStmtDefault() {
    var s;
    return this._rule("t", false, [], null, this["t"]) && (s = this._getIntermediate(), true) && this._exec([ keyword("default"), s ]);
};

YetAnotherJSHighlighter.prototype["throwStmt"] = function $throwStmt() {
    var s1, e, s2;
    return this._rule("t", false, [], null, this["t"]) && (s1 = this._getIntermediate(), true) && this._rule("t", false, [], null, this["t"]) && (e = this._getIntermediate(), true) && this._rule("t", false, [], null, this["t"]) && (s2 = this._getIntermediate(), true) && this._exec(w("throw", keyword("throw"), s1, e, s2));
};

YetAnotherJSHighlighter.prototype["tryStmt"] = function $tryStmt() {
    return this._atomic(function() {
        var s1, b, s2, c, s3, f, s4;
        return this._rule("t", false, [], null, this["t"]) && (s1 = this._getIntermediate(), true) && this._rule("t", false, [], null, this["t"]) && (b = this._getIntermediate(), true) && this._rule("t", false, [], null, this["t"]) && (s2 = this._getIntermediate(), true) && this._rule("t", false, [], null, this["t"]) && (c = this._getIntermediate(), true) && this._rule("t", false, [], null, this["t"]) && (s3 = this._getIntermediate(), true) && this._rule("t", false, [], null, this["t"]) && (f = this._getIntermediate(), true) && this._rule("t", false, [], null, this["t"]) && (s4 = this._getIntermediate(), true) && this._exec(w("try", keyword("try"), s1, b, s2, c, s3, f, s4));
    }) || this._atomic(function() {
        var s1, b, s2, c;
        return this._rule("t", false, [], null, this["t"]) && (s1 = this._getIntermediate(), true) && this._rule("t", false, [], null, this["t"]) && (b = this._getIntermediate(), true) && this._rule("t", false, [], null, this["t"]) && (s2 = this._getIntermediate(), true) && this._rule("t", false, [], null, this["t"]) && (c = this._getIntermediate(), true) && this._exec(w("try", keyword("try"), s1, b, s2, c));
    });
};

YetAnotherJSHighlighter.prototype["tryStmtCatch"] = function $tryStmtCatch() {
    var s1, be, s2, c;
    return this._rule("t", false, [], null, this["t"]) && (s1 = this._getIntermediate(), true) && this._rule("t", false, [], null, this["t"]) && (be = this._getIntermediate(), true) && this._rule("t", false, [], null, this["t"]) && (s2 = this._getIntermediate(), true) && this._rule("t", false, [], null, this["t"]) && (c = this._getIntermediate(), true) && this._exec([ keyword("catch"), s1, be, s2, c ]);
};

YetAnotherJSHighlighter.prototype["tryStmtFinally"] = function $tryStmtFinally() {
    var s1, c;
    return this._rule("t", false, [], null, this["t"]) && (s1 = this._getIntermediate(), true) && this._rule("t", false, [], null, this["t"]) && (c = this._getIntermediate(), true) && this._exec([ keyword("finally"), s1, c ]);
};

YetAnotherJSHighlighter.prototype["returnStmt"] = function $returnStmt() {
    return this._atomic(function() {
        var s1, c, s2;
        return this._rule("t", false, [], null, this["t"]) && (s1 = this._getIntermediate(), true) && this._rule("t", false, [], null, this["t"]) && (c = this._getIntermediate(), true) && this._rule("t", false, [], null, this["t"]) && (s2 = this._getIntermediate(), true) && this._exec(w("return", keyword("return"), s1, c, s2));
    }) || this._atomic(function() {
        var s2;
        return this._rule("t", false, [], null, this["t"]) && (s2 = this._getIntermediate(), true) && this._exec(w("return", keyword("return"), s2));
    });
};

YetAnotherJSHighlighter.prototype["withStmt"] = function $withStmt() {
    var c;
    return this._rule("stmtWithExprAndStmt", false, [ "with" ], null, this["stmtWithExprAndStmt"]) && (c = this._getIntermediate(), true) && this._exec(w("with", c));
};

YetAnotherJSHighlighter.prototype["labelStmt"] = function $labelStmt() {
    var l, s1, s2, c;
    return this._rule("t", false, [], null, this["t"]) && (l = this._getIntermediate(), true) && this._rule("t", false, [], null, this["t"]) && (s1 = this._getIntermediate(), true) && this._rule("t", false, [], null, this["t"]) && (s2 = this._getIntermediate(), true) && this._rule("t", false, [], null, this["t"]) && (c = this._getIntermediate(), true) && this._exec(w("label", l, s1, punctuation(":"), s2, c));
};

YetAnotherJSHighlighter.prototype["exprStmt"] = function $exprStmt() {
    var e;
    return this._rule("t", false, [], null, this["t"]) && (e = this._getIntermediate(), true) && this._exec(w("expr-stmt", e));
};

YetAnotherJSHighlighter.prototype["t"] = function $t() {
    var t, r;
    return this._list(function() {
        return this._skip() && (t = this._getIntermediate(), true) && this._rule("apply", false, [ t ], null, this["apply"]) && (r = this._getIntermediate(), true);
    }) && this._exec(r);
};

YetAnotherJSHighlighter.prototype["emptyStmt"] = function $emptyStmt() {
    return this._exec(punctuation(";"));
};

YetAnotherJSHighlighter.prototype["topLevel"] = function $topLevel() {
    var c;
    return this._rule("topLevel", false, [], KrasotaJSSerializer, KrasotaJSSerializer.prototype["topLevel"]) && (c = this._getIntermediate(), true) && this._exec('<pre class="yajsh">' + c + "</pre>");
};

var slice = Array.prototype.slice;

function w(cls, content) {
    return [ '<span class="', cls, '">', slice.call(arguments, 1), "</span>" ];
}

function punctuation(content) {
    return w("punctuation", content);
}

function keyword(cls, content) {
    if (arguments.length === 1) {
        content = cls;
        cls = "";
    }
    return w("keyword" + (cls ? " " + cls : ""), content);
}